Welcome to ClientVPS Mirrors

Help for package RcppClassic
Title: Deprecated 'classic' 'Rcpp' 'API'
Version: 0.9.14
Date: 2026-03-14
Description: The 'RcppClassic' package provides a deprecated C++ library which facilitates the integration of R and C++. New projects should use the new 'Rcpp' 'API' in the 'Rcpp' package.
Imports: Rcpp (≥ 1.1.1), methods
Suggests: tinytest
LinkingTo: Rcpp
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
MailingList: Please send questions and comments about Rcpp to rcpp-devel@lists.r-forge.r-project.org
URL: https://github.com/eddelbuettel/rcppclassic, https://dirk.eddelbuettel.com/code/rcpp.classic.html
BugReports: https://github.com/eddelbuettel/rcppclassic/issues
VignetteBuilder: Rcpp
NeedsCompilation: yes
Packaged: 2026-03-14 11:39:56 UTC; edd
Author: Dirk Eddelbuettel ORCID iD [aut, cre], Romain Francois ORCID iD [aut], David Reiss [ctb], Dominick Samperi [aut] (Initial code during 2005-2006)
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-03-15 17:00:02 UTC

Deprecated R / C++ interface

Description

The RcppClassic package provides the classic Rcpp API.

Author(s)

Dominick Samperi wrote the initial versions of Rcpp (and RcppTemplate) during 2005 and 2006. Dirk Eddelbuettel made some additions, and became maintainer in 2008. Dirk Eddelbuettel and Romain Francois have been extending Rcpp since 2009.

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.